=======
History
=======

0.2.0 (under development)
-------------------------

* Better handling for a large variety of error conditions
* Proper fallback mechanism implemented
* Various bug fixes:
  * Avoid output ``.elm`` files with no exports
  * Bugs with HTML attributes and non-string message args


0.1.0 (2018-07-27)
------------------

* First release on PyPI.
